Package 'distanceMCMC'

Title: Functions to Fit Distance Sampling Models Via MCMC Using Nimble
Description: Functions for Bayesian distance sampling models for use within nimble.
Authors: Devin Johnson [aut, cre]
Maintainer: Devin Johnson <[email protected]>
License: CC0
Version: 0.0.9003
Built: 2026-05-14 15:30:54 UTC
Source: https://github.com/dsjohnson/distanceMCMC

Help Index


Distance sampling distributions that can be used in nimble models

Description

ddist distance sampling distributions for half-normal and hazard rate models.

Usage

ddist_hn(x, sigma, w, log = 0)

ddist_hr(x, sigma, b, w, log = 0)

hr_integrand(x, pars)

rdist_hn(n, sigma, w)

rdist_hr(n, sigma, b, w)

esw_dist_hn(sigma, w, prob = 0)

esw_dist_hr(sigma, b, w, prob = 0)

Arguments

x

distance observations. either a single value (dHN) or a vector of values (dHN_V)

sigma

scale parameter for detection models

w

right truncation distance for integration of the likelihood function

log

if TRUE, return the log-likelihood

b

Power parameter for hazard rate model.

pars

Parameters for hazard rate function. Used in hr_integrand(). Not intended for practitioner use.

n

number of random values to generate

prob

Logical. Should the function return the marginal detection probability instead of effective strip width (ESW)

Author(s)

Devin Johnson